@@ -1,4 +1,5 @@
-class InvalidKey(Exception):
+class NoKey(Exception):
     pass
+
 class Not200(Exception):
     pass
\ No newline at end of file
